==> evac-1.0.0.tar.gz: evac/tests/src/Unit/Utility/SpoofCheckValidatorTest.php <==
<?php

namespace Drupal\Tests\evac\Unit\Utility;

use Drupal\evac\Utility\SpoofCheckValidator;
use Egulias\EmailValidator\Validation\Extra\SpoofCheckValidation;
use PHPUnit\Framework\TestCase;

/**
 * Tests the SpoofCheckValidator utility class.
 *
 * @coversDefaultClass \Drupal\evac\Utility\SpoofCheckValidator
 * @group evac
 */
class SpoofCheckValidatorTest extends TestCase {

  /**
   * @covers ::isValid
   */
  public function testIsValid() {
    // Note that \Drupal\Component\Utility\EmailValidator wraps
    // \Egulias\EmailValidator\EmailValidator so we don't do anything more than
    // test that the wrapping works since the dependency has its own test
    // coverage.
    $validator = new SpoofCheckValidator();

    // The examples are copied from
    // \Egulias\EmailValidator\Tests\EmailValidator\Validation\Extra\SpoofCheckValidationTest.
    // Cyrillic.
    $valid = 'Кириллица@Кириллица';
    $this->assertTrue($validator->isValid($valid), "Email $valid should pass spoof check.");

    // Mixed.
    $invalid = 'Кириллицаlatin漢字ひらがなカタカナ';
    $this->assertFalse($validator->isValid($invalid), "Email $invalid should fail DNS check.");
  }

  /**
   * @covers ::isValid
   */
  public function testIsValidException() {
    $validator = new SpoofCheckValidator();
    $this->expectException(\BadMethodCallException::class);
    $this->expectExceptionMessage('Calling \Drupal\evac\Utility\SpoofCheckValidator::isValid() with the second argument is not supported. See https://www.drupal.org/node/2997196');
    $validator->isValid('example@example.com', (new SpoofCheckValidation()));
  }

}

==> evac-1.0.1.tar.gz: evac/tests/src/Unit/Utility/SpoofCheckValidatorTest.php <==
<?php

namespace Drupal\Tests\evac\Unit\Utility;

use Drupal\evac\Utility\SpoofCheckValidator;
use Egulias\EmailValidator\Validation\Extra\SpoofCheckValidation;
use PHPUnit\Framework\TestCase;

/**
 * Tests the SpoofCheckValidator utility class.
 *
 * @coversDefaultClass \Drupal\evac\Utility\SpoofCheckValidator
 * @group evac
 */
class SpoofCheckValidatorTest extends TestCase {

  /**
   * @covers ::isValid
   */
  public function testIsValid() {
    // Note that \Drupal\Component\Utility\EmailValidator wraps
    // \Egulias\EmailValidator\EmailValidator, so we don't do anything more than
    // test that the wrapping works since the dependency has its own test
    // coverage.
    $validator = new SpoofCheckValidator();

    // The examples are copied from
    // \Egulias\EmailValidator\Tests\EmailValidator\Validation\Extra\SpoofCheckValidationTest.
    // Cyrillic.
    $valid = 'Кириллица@Кириллица';
    $this->assertTrue($validator->isValid($valid), "Email $valid should pass spoof check.");

    // Mixed.
    $invalid = 'Кириллицаlatin漢字ひらがなカタカナ';
    $this->assertFalse($validator->isValid($invalid), "Email $invalid should fail DNS check.");
  }

  /**
   * @covers ::isValid
   */
  public function testIsValidException() {
    $validator = new SpoofCheckValidator();
    $this->expectException(\BadMethodCallException::class);
    $this->expectExceptionMessage('Calling \Drupal\evac\Utility\SpoofCheckValidator::isValid() with the second argument is not supported. See https://www.drupal.org/node/2997196');
    $validator->isValid('example@example.com', (new SpoofCheckValidation()));
  }

}
